ValidatingAdmissionPolicyStatus

Struct ValidatingAdmissionPolicyStatus 

pub struct ValidatingAdmissionPolicyStatus {
    pub conditions: Option<Vec<Condition>>,
    pub observed_generation: Option<i64>,
    pub type_checking: Option<TypeChecking>,
}
ValidatingAdmissionPolicyStatus represents the status of an admission validation policy.

Fields

conditions: Option<Vec<Condition>>

conditions represent the latest available observations of a policy’s current state.

observed_generation: Option<i64>

observedGeneration is the generation observed by the controller.

type_checking: Option<TypeChecking>

typeChecking contains the results of type checking for each expression. Presence of this field indicates the completion of the type checking.